#ifdef KDE3
#	include <khtml.h>
#else // KDE 2
#	include <khtml_part.h>
#	include <khtmlview.h>
#endif
#include <kapplication.h>
#include <klocale.h>
#include <kconfig.h>
#include <kglobal.h>
#include <qlayout.h>
#include <qlineedit.h>

#include "kwebmin.h"

KWebmin::KWebmin(QWidget* parent, const char* name)
{
	setButtons(0);

	QBoxLayout* layout = new QBoxLayout(this, QBoxLayout::TopToBottom);

	location = new QLineEdit(this);

	layout->addWidget(location);

#ifdef KDE3
	html = new KHTMLWidget(this);

	layout->addWidget(html);
#else // KDE2
	html = new KHTMLPart(this, 0, 0, 0, KHTMLPart::BrowserViewGUI);

	layout->addWidget(html->view());
#endif
	connect(
		html->browserExtension(),
		SIGNAL(openURLRequest(const KURL&, const KParts::URLArgs&)),
		this,
		SLOT(openURLRequest(const KURL&, const KParts::URLArgs&)));


	KConfig* config = new KConfig("kwebmin");

	config->setGroup("General");

	QString url = config->readEntry("WebminLocation", "https://localhost:10000/");
	config->writeEntry("WebminLocation", url);
	location->setText(url);

	html->setJScriptEnabled(true);
	html->setJavaEnabled(true);

	html->setURLCursor(QCursor(PointingHandCursor));
	html->openURL(url);

	connect(
		location,
		SIGNAL(returnPressed()),
		this,
		SLOT(changeLocation()));

	html->show();
}

KWebmin::~KWebmin()
{
}

QString KWebmin::quickHelp()
{
	return i18n("Access to Webmin configuration interface");
}

void KWebmin::openURLRequest(const KURL& url, const KParts::URLArgs& args)
{
	location->setText(url.url());
	html->openURL(url);
}

void KWebmin::changeLocation()
{
	html->openURL(location->text());
}

extern "C"
{
	KCModule* create_kwebmin(QWidget* parent, const char* name)
	{
		KGlobal::locale()->insertCatalogue("kwebmin");

		return new KWebmin(parent, name);
	}
};

